﻿using System.Windows;
using System.Windows.Media;

using MindFusion.Diagramming.Wpf;
using MindFusion.Diagramming.Wpf.Layout;

using Orientation=MindFusion.Diagramming.Wpf.Layout.Orientation;


namespace PertNetwork
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();

			var network = new[]
			{
				new Activity { Name = "A", From = "10", To = "30", Time = 3 },
				new Activity { Name = "B", From = "10", To = "20", Time = 4 },
				new Activity { Name = "C", From = "20", To = "50", Time = 3 },
				new Activity { Name = "D", From = "30", To = "40", Time = 1 },
				new Activity { Name = "E", From = "30", To = "50", Time = 3 },
				new Activity { Name = "F", From = "40", To = "50", Time = 3 }
			};

			BuildChart(network);
		}

		void BuildChart(Activity[] network)
		{
			diagram.BackBrush = new SolidColorBrush(Colors.White);

			// create diagram nodes for each milestone
			foreach (var activity in network)
			{
				if (diagram.FindNodeById(activity.From) == null)
				{
					var node = diagram.Factory.CreateShapeNode(bounds, Shapes.Ellipse);
					node.Id = node.Text = activity.From;
				}

				if (diagram.FindNodeById(activity.To) == null)
				{
					var node = diagram.Factory.CreateShapeNode(bounds, Shapes.Ellipse);
					node.Id = node.Text = activity.To;
				}
			}

			// create a diagram link for each activity
			foreach (var activity in network)
			{
				var link = diagram.Factory.CreateDiagramLink(
					diagram.FindNodeById(activity.From),
					diagram.FindNodeById(activity.To));

				var label1 = link.AddLabel(activity.Name);
				label1.RelativeTo = RelativeToLink.Segment;
				label1.Index = 0;
				label1.VerticalOffset = -20;
				label1.TextBrush = new SolidColorBrush(Colors.Red);

				var label2 = link.AddLabel(string.Format("t={0}mo", activity.Time));
				label2.RelativeTo = RelativeToLink.Segment;
				label2.Index = 0;
				label2.VerticalOffset = 10;
				label2.TextBrush = new SolidColorBrush(Colors.Blue);
			}

			// arrange the diagram from left to right
			var layout = new LayeredLayout();
			layout.Margins = new Size(100, 100);
			layout.EnforceLinkFlow = true;
			layout.Orientation = Orientation.Horizontal;
			layout.Arrange(diagram);
		}

		Rect bounds = new Rect(0, 0, 40, 40);
	}

	public class Activity
	{
		// activity name
		public string Name { get; set; }

		// start milestone name
		public string From { get; set; }

		// end milestone  name
		public string To { get; set; }

		// time in months
		public int Time { get; set; }
	}
}